// data.js
import { slider, display, nameMapping } from './globals.js';
import { initMap, renderMap } from './map.js';
import { initPlot, updateLinePlot } from './plot.js';

var mapData;
var gdpDataMap;
var selectedCountry = 'United States';

export function loadData() {
  // var mapData;
  // var gdpDataMap;
  // var selectedCountry = 'United States';
  const mapUrl =
    'https://raw.githubusercontent.com/holtzy/D3-graph-gallery/master/DATA/world.geojson';
  const gdpUrl =
    'https://raw.githubusercontent.com/Heffnt/DataViz/main/CleanedRealPerCapitaGDPValues%20-%20GDP%20Per%20Cap.csv';

  Promise.all([d3.json(mapUrl), d3.csv(gdpUrl)]).then(
    ([mapDataRaw, gdpData]) => {
      console.log('mapJson: ' + mapDataRaw);
      console.log('gdpCsv: ' + gdpData);
      mapData = mapDataRaw;

      mapData.features.forEach((f) => {
        f.properties.name = normalizeCountryName(
          f.properties.name,
        );
      });

      // Create a new map for GDP data
      gdpDataMap = new Map();
      gdpData.forEach((row) => {
        if (row.Type === 'C') {
          let countryKey = normalizeCountryName(
            row.Country,
          );
          let yearData = {};
          Object.keys(row).forEach((key) => {
            if (key.startsWith('y') && !isNaN(+row[key])) {
              yearData[key] = +row[key];
            }
          });
          gdpDataMap.set(countryKey, yearData);
        }
      });

      mapData.features.forEach((f) => {
        f.properties.name = normalizeCountryName(
          f.properties.name,
        );
      });
      console.log('mapData: ' + mapData);

      // Initialize map and plot
      initMap(mapData, gdpDataMap);
      initPlot(gdpDataMap, selectedCountry);

      // Initial render
      render();
    },
  );

  slider.oninput = function () {
    render();
  };
}

function normalizeCountryName(name) {
  return nameMapping[name] || name;
}

function render() {
  updateLinePlot();
  renderMap();

  display.innerHTML = slider.value;
}
